```
                             _        
                            | |       
 _ __  _   _ ___ _ __  _   _| | _____ 
| '_ \| | | / __| '_ \| | | | |/ / _ \
| |_) | |_| \__ \ |_) | |_| |   <  __/
| .__/ \__, |___/ .__/ \__, |_|\_\___|
| |     __/ |   | |     __/ |         
|_|    |___/    |_|    |___/          
                                      
                                       

// pyspyke
// Curator: Josh Groeschl
```

# pyspyke
Python application to spike a systens memory to desired percentage allotments.

__Installation__

- Clone the repo and run:

- ```pip3 install --editable .```

- After installatino is complete just run: ```pyspyke --time 1 --percentage 60```

- This call withh hold the percentage at 60% for 1 minute. 
- Use the flags accordingly to adjust the necessary parameters.

